ua_parse: Parse a vector of user agents into a data frame

View source: R/uaparser.R

ua_parseR Documentation

Parse a vector of user agents into a data frame

Description

Takes in a character vector of user agent strings and returns a data frame classed as tibble. of parsed user agents.

Usage

ua_parse(user_agents, .progress = FALSE)

get_cache()

Arguments

user_agents

a character vector of user agents

.progress

if 'TRUE' will display a progress bar in interactive mode

Value

a data frame classed as tibble with columns for user agent family, major & minor versions plus patch level along with OS family and major & minor versions plus device brand and model.

Note

The regex YAML from uap-core is now updated when the package is rebuilt. The effective date can be found in the NEWS file.

References

<https://github.com/ua-parser/uap-core/>

Examples

ua_parse(paste0("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, ",
                "like Gecko) Ubuntu/11.10 Chromium/15.0.874.106 ",
                "Chrome/15.0.874.106 Safari/535.2", collapse=""))

uaparserjs documentation built on April 1, 2026, 5:06 p.m.