uaparserjs: Parse 'User-Agent' Strings

uaparserjsR Documentation

Parse 'User-Agent' Strings

Description

Despite there being a section in RFC 7231 <https://tools.ietf.org/html/rfc7231#section-5.5.3> defining a suggested structure for 'User-Agent' headers this data is notoriously difficult to parse consistently. Tools are provided that will take in user agent strings and return structured R objects. This is a 'V8'-backed package based on the 'ua-parser' project <https://github.com/ua-parser>.

Details

The package incorporates regular expressions and test data from the ua parser project that are copyrighted by Google and the UA Parser contributors and are used under an Apache 2 license. See the UA parser project for details.

Author(s)

Bob Rudis (@hrbrmstr)

See Also

Useful links:


uaparserjs documentation built on April 1, 2026, 5:06 p.m.