| ua_parse | R Documentation |
Takes in a character vector of user agent strings and returns a data frame classed as tibble. of parsed user agents.
ua_parse(user_agents, .progress = FALSE)
get_cache()
user_agents |
a character vector of user agents |
.progress |
if 'TRUE' will display a progress bar in interactive mode |
a data frame classed as tibble with columns for user agent family, major & minor versions plus patch level along with OS family and major & minor versions plus device brand and model.
The regex YAML from uap-core is now updated when the package is rebuilt. The effective date can be found in the NEWS file.
<https://github.com/ua-parser/uap-core/>
ua_parse(paste0("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, ",
"like Gecko) Ubuntu/11.10 Chromium/15.0.874.106 ",
"Chrome/15.0.874.106 Safari/535.2", collapse=""))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.